@@ -19,12 +19,6 @@ class JunoProvider:
         self.server = server
         self.auth_server = '%s/authorization-server' % server
         self.resource_server = '%s/api-integration' % server
-        self.access_token = self.get_access_token()
-        self.headers = {
-            'Authorization': 'Bearer %s' % self.access_token,
-            'X-Api-Version': '2',
-            'X-Resource-Token': self.resource_token
-        }
         super(JunoProvider, self).__init__(**kwargs)
 
     def get_access_token(self):
@@ -34,12 +28,19 @@ class JunoProvider:
         content = json.loads(response.content)
         return content.get('access_token')
 
+    def get_headers(self):
+        return {
+            'Authorization': 'Bearer %s' % self.get_access_token(),
+            'X-Api-Version': '2',
+            'X-Resource-Token': self.resource_token
+        }
+
     def tokenize_credit_card(self, credit_card_hash):
         url = '%s/credit-cards/tokenization' % self.resource_server
         data = {
             'creditCardHash': credit_card_hash
         }
-        response = requests.post(url, json=data, headers=self.headers)
+        response = requests.post(url, json=data, headers=self.get_headers())
         if response.status_code == 200:
             return json.loads(response.content)
         raise Exception(response.text)
@@ -47,7 +48,7 @@ class JunoProvider:
     def get_charge(self, charge_id):
         if charge_id:
             url = '%s/charges/%s/' % (self.resource_server, charge_id)
-            response = requests.get(url, headers=self.headers)
+            response = requests.get(url, headers=self.get_headers())
             if response.status_code == 200:
                 return json.loads(response.content.decode())
         raise Exception(response.text)
@@ -69,7 +70,7 @@ class JunoProvider:
                 'notify': False
             }
         }
-        response = requests.post(url, json=data, headers=self.headers)
+        response = requests.post(url, json=data, headers=self.get_headers())
         if response.status_code == 200:
             return response.content
         raise Exception(response.text)
@@ -94,28 +95,28 @@ class JunoProvider:
             },
             'creditCardDetails': credit_card_details
         }
-        response = requests.post(url, json=data, headers=self.headers)
+        response = requests.post(url, json=data, headers=self.get_headers())
         if response.status_code == 200:
             return response.content
         raise Exception(response.text)
 
     def list_webhooks(self):
         url = '%s/notifications/webhooks' % self.resource_server
-        response = requests.get(url, headers=self.headers)
+        response = requests.get(url, headers=self.get_headers())
         if response.status_code == 200:
             return response.content
         raise Exception(response.text)
 
     def get_webhook(self, wbh_id):
         url = '%s/notifications/webhooks/%s' % (self.resource_server, wbh_id)
-        response = requests.get(url, headers=self.headers)
+        response = requests.get(url, headers=self.get_headers())
         if response.status_code == 200:
             return response.content
         raise Exception(response.text)
 
     def delete_webhook(self, wbh_id):
         url = '%s/notifications/webhooks/%s' % (self.resource_server, wbh_id)
-        response = requests.delete(url, headers=self.headers)
+        response = requests.delete(url, headers=self.get_headers())
         if response.status_code == 200:
             return response.content
         raise Exception(response.text)
